
# q-expansion of newform 3.25.b.b, downloaded from the LMFDB on 11 May 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 3
weight = 25
poly_data = [250659115499520, 0, 17425276096, 0, 253102, 0, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0], 1], [[0, 18, 0, 0, 0, 0], 1], [[-519220416540672, 4583765471040, -8746814592, 158192658, -22464, 927], 1041302528], [[-624717182509056, -4574393748288, 11341271808, -158192658, 162432, -927], 520651264], [[1452164483653632, 2340669617528256, 46328530176, 36839351862, 252288, 129501], 520651264], [[9641799262384128, 4583765471040, 370146519936, 158192658, 2217024, 927], 1041302528]]

hecke_ring_character_values = [[2, [-1, 0, 0, 0, 0, 0]]]
aps_data = [[0, 1, 0, 0, 0, 0], [-102807, 16, 1, 0, 0, 0], [0, -16866, -112, 18, 1, -4], [331344146, 1631, 238, -1631, 0, -3500], [0, 26304201, -4409240, 696663, -5500, -145508], [-12257073010654, -2561884, 9982216, 2561884, 0, -4858448], [0, 94108902628, 140367008, -22237668, -48344, 4691792], [1015869915579026, 463700073, -552650910, -463700073, 0, -374749236], [0, 2117603796670, -10861035344, 1725359490, 21358352, -367730072], [0, -45148749137150, 230294278896, -36522361458, -221627373, 7735576596], [-189640651829203438, 242924626235, -450929879834, -242924626235, 0, -34919372636], [-2338770582619803934, -4499220946884, 8465974516920, 4499220946884, 0, 532467376848], [0, 1655869609209524, 16439879169120, -2597694903828, 19822367310, 542710007688], [-19100549691423725614, 10246609828721, -25523634893582, -10246609828721, 0, 5030415236140], [0, -12098016788479372, 118596965862176, -18748105958772, 111551135272, 3923485226000], [0, 48677706490416630, 292397684695248, -46340112334086, -164295965019, 9790401747180], [0, 213729180666636225, 3026239637921192, -478266668505441, 3329778120304, 99986713765292], [1668846402432472695842, 491097180743180, -1214195192957096, -491097180743180, 0, 232000831470736], [-907514515405180474414, -742910517139699, 1574124385937002, 742910517139699, 0, -88303351657604], [0, 756674531285537362, -1499530548451120, 250851726975726, 50347713016120, -63410408419336], [1204831473200573840066, -5883100163857584, 13178605767253920, 5883100163857584, 0, -1412405439538752], [-70580807351013804652654, 12499954825131803, -19933107431287130, -12499954825131803, 0, -5066802218976476], [0, 3078798376008577387, -157661954685329736, 24944579388311157, -69612888247692, -5236835052644940], [0, 14222732564527013960, 260927043593934208, -41461087139147304, -553644637903954, 8845206689905528], [-235267911709305408403774, 361678218445291556, -833583073473213176, -361678218445291556, 0, 110226636582630064], [0, 52362222771967077830, -157570870548209200, 25348548880918890, 1499353915446625, -5652190062392740], [725897681123359113423506, -66612230017534729, 398818032168218782, 66612230017534729, 0, -265593572133149324], [0, -188089317865087337643, 3049229310939339720, -482104895239555317, 2586546221900520, 100951231372137852], [30221281658409837619106, 198519731212239228, -645915669804378312, -198519731212239228, 0, 248876207379899856], [0, -593972676399383034576, 867978721191019520, -139737596909399280, -8653622703079460, 31240256760521840], [4705281352260133491513746, 5216597851231991091, -11973946922149548714, -5216597851231991091, 0, 1540751219685566532], [0, -5206813583618667084197, -1147923593778096200, 197111352836271429, 57587939330273240, -53620903614009404], [0, -108527330347117406804, -32899402437895467744, 5176341815479797492, -122738389451193378, -1063916510742864024], [18571628072436913455661586, -4048055628504863587, 2730588641819914378, 4048055628504863587, 0, 5365522615189812796], [0, 3908832710249983510310, 155110731174293497680, -24595384629603171510, -135695726275128915, 5206543232816484300], [60873034950863113390903442, 1175804129151102095, -31903589598009434546, -1175804129151102095, 0, 29551981339707230356], [108228457037459748308444066, -104779316184465607324, 214224924794791829128, 104779316184465607324, 0, -4666292425860614480], [93865873167827325397198226, 107432656975989067521, -118122530100571836654, -107432656975989067521, 0, -96742783851406298388], [0, -92300350315232334779790, 378461234487482527952, -60197683895699269554, -1029956631929509856, 12890029584763953560], [0, 25680554915135788384914, -715575808561648487696, 114101196712051263678, 3006351336713449223, -24654220641845202716], [0, 188840930049995032046575, 23272841877358404056, -3583013793655453263, 381948138473602672, 673908558985652756], [420412261867945956315502562, -632710387645951281180, 1191650458527013115784, 632710387645951281180, 0, 73770316764889446576], [0, -15466876557727662973736, 3391451853817876528320, -538102958430367723608, -4211555909514774840, 114171476703133157568], [-874634407499725890767790334, 368395703719099089776, -188964849243064465952, -368395703719099089776, 0, -547826558195133713600], [0, 14300626648657393924166, 102468270332296549072, -13859770224205687446, 8866397169029748089, 1051236432668618812], [172605012707879594369343506, 1598122481120034433743, -3324503460188831686962, -1598122481120034433743, 0, 128258497948762819476], [-2813646504251576784636725038, 3263192476527532364165, -6983061290624020985894, -3263192476527532364165, 0, 456676337568956257564], [6306042642351740478620127506, -664249631408686824469, -1840492475662263502010, 664249631408686824469, 0, 3168991738479637150948], [0, 41920489261311448344639, 19721609287293290825176, -3118218092005723683039, 16387669308927616052, 653016931094062329892], [-19821080768885215931269220254, 4299203172369673605188, -6787787524017975678392, -4299203172369673605188, 0, -1810618820721371531984], [0, -825964885134884919389312, -56285777299443947308864, 8915432292828487314144, 13190826561983713402, -1879710130397993900536], [0, 7043323647103516682459860, 8969417527765237124128, -1428276562344290302164, -30445451680479090664, 307099371373635661648], [-39396509229629375910999169918, -11483442057924107064160, 26462992303678298003776, 11483442057924107064160, 0, -3496108187830083875456], [0, -11349153680707825737055555, 31317743240355046021000, -4913300882724116580765, 170031738745371397100, 998582977679735828140], [0, 4860272338852332857006744, 52877045636319546442944, -8372991745889859765528, -2973200522243420232, 1763361041349916460160], [0, -14425243144914143580261934, 29887265725334186185424, -4788388430002783755666, -210892588093266036152, 1052480214336010482488], [0, -18771230493071346658659870, 60574393054145791365744, -9551458155829964891922, 148077791536695278703, 1979659024061740971204], [67506328297854528014378036882, 35802029010857937501195, -43569247485834046561914, -35802029010857937501195, 0, -28034810535881828440476], [85429993365041423786139502946, 58070280750976603295516, -91934114974549725676424, -58070280750976603295516, 0, -24206446527403480914608], [0, 3724540363600992174650688, -30688700801518374975680, 4700053993805397251424, -596213624131295448970, -863966393615600379464], [-72276128340511953810543684334, 11146295698036293644021, -50485779344652572118086, -11146295698036293644021, 0, 28193187948579984830044], [0, 9780891035268357005510278, -158181594008312074583600, 25006961023852299381162, -144217602989171604655, -5234261772813290058212], [540020670353362863877489151186, 138311445576104121660021, -425890553066231828494662, -138311445576104121660021, 0, 149267661914023585174620], [0, 68361932653019797254924446, -1017425510849919054949200, 160337005939205998828578, -2832624795116943268920, -33158817082966116959928], [164603377539361269315910168706, 324244654427718103555676, -440930680153519953409544, -324244654427718103555676, 0, -207558628701916253701808], [0, 127686991287555119450799914, 2088316316893913980382000, -330084826916526844255386, 2119712218785759894115, 69045287304787596707636], [-1352690946924706524873072921838, -124342911707833003623955, 286570886291512255324714, 124342911707833003623955, 0, -37885062875846248076804], [369677604590669413315411573826, 817830756532469332695476, -1937079839547672031199960, -817830756532469332695476, 0, 301418326482733365809008], [0, -514844629555498956184246667, 1638066609305406090440776, -258303228939431039363157, 3964940752218468587372, 53544902776255278058060], [-1295910926581983260550275447134, -1374664249502201667091372, 2360628957553004713213288, 1374664249502201667091372, 0, 388699541451398620969456], [0, 216574215090818581619724832, -1486696912578629222327808, 232987126235602630075488, -9024568460051237974056, -47150012163273977284512], [0, 258230793445711805160164330, -4741449741903670385188208, 755549722854141128082774, 18075676447724939104904, -162868505116182329934248], [-4801250662101433514195586961774, 806360526188490161600891, -2053942577190180386881178, -806360526188490161600891, 0, 441221524813200063679396], [-1664413860305733473274353296414, -427164528005255784335164, 486813943428574429189960, 427164528005255784335164, 0, 367515112581937139480368], [6790174561555632690833410355666, 3222337357794736441005753, -6825337927978272905408766, -3222337357794736441005753, 0, 380663212388800023397260], [0, 109568386989028540113671304, 8498090522596456502339648, -1347364755651422242971144, -6876585901187362877624, 285103440326865180178688], [0, 1516086374607396331351010190, -7742103086345808417616112, 1226225461984473775498146, 1471774923952910158481, -258462576191247723296132], [2629261989272138056504606901666, 6888427024449127847088396, -15379821265894705529538216, -6888427024449127847088396, 0, 1602967216996449835361424], [0, 1636655010497112223087403500, -13407819883513052287842080, 2135204566612748763521940, 46124068961933067301040, -459227081173617227541680], [-3075922537741505925263465320894, -3394932195161109704790832, 9061394860139996345349280, 3394932195161109704790832, 0, -2271530469817776935767616], [0, 5394078574651808018924610215, 11923467383661676848633624, -1890768115525014153675207, -10821674169682447405812, 400334692567304547596004], [-24896951804683053469892247035038, -3358076207276802516276940, 8092981169593698483796264, 3358076207276802516276940, 0, -1376828755040093451242384], [0, -5566854891849257888050413372, -4756956187737016854541920, 751901240648784205864764, -4813084035912985391400, -157281717181657099047024], [34001121618053037342615716046146, -13400312454408265005482124, 33683180092553435750877864, 13400312454408265005482124, 0, -6882555183736905739913616], [-4901931223990077818060964932974, 11689493698234578346847423, -32252171670225909081631826, -11689493698234578346847423, 0, 8873184273756752387936980], [0, -3904622184263050922765233419, 56454511039633345827092296, -8984868003525620024460117, -173389083438776006889388, 1928054123571451796073580], [0, 4310510182410523514462367340, -27353154678994157681272480, 4305514179981158566815060, -95257415723436497699060, -886369845106888856656000], [15042813807382310786366208993986, 12705350102524693231487696, -24572543808433893398218592, -12705350102524693231487696, 0, -838156396615493064756800], [0, -13297064729529388867645009094, 86046304048778481603493680, -13586214234624815495663082, 141689649119165343337815, 2830426228527505295226372], [-27887118345797020438640028508654, 10477053136126891974179891, -4884430693509444495565994, -10477053136126891974179891, 0, -16069675578744339452793788], [0, -701270501487692837737700845, -60114609129830458512721928, 9446107908841284077561421, -270144512682019451073316, -1931781767612476763471180], [0, 21069552674972101315320652040, -90464548036304492356682944, 14451557214115211427319032, 480014156376250515665872, -3143488709577149882733664], [-122780658592093495996169486207854, -95278883721618509136417129, 189925028277342519792162270, 95278883721618509136417129, 0, 632739165894498480671988], [0, -7122155019426791883745654371, -16295111911414153975930360, 2521967461340488619221827, -217844717375321601126800, -485078472413719372230532], [-162652840743687295882825667102254, -34597792331205195927570427, 29734402083561831694687450, 34597792331205195927570427, 0, 39461182578848560160453404], [0, -13406301738327862168154400194, -363612668265729154574643280, 57576454512270470939261826, 16682638237580493537400, -12124870979054326617431416], [0, 7538537068849749920710548490, 160628754188344338923428912, -25605269915243856843011706, -646439382835011925507981, 5526675641700814477583092], [0, 1237917810891781146820558892, 367225383296496427717461280, -57933881009363549192767884, 788017547181444484363070, 12030708097301495728085224], [-422386640518864062151035040639534, 5267342213821685294685441, -52652911040524265822661870, -5267342213821685294685441, 0, 42118226612880895233290988], [-266898663373874263044419865707998, 64038388434184707132969660, -56009157654779578845353544, -64038388434184707132969660, 0, -72067619213589835420585776], [-835233825789872064688769432628334, 206411113316422716110861921, -416614982252878729824363566, -206411113316422716110861921, 0, 3792755620033297602639724], [0, -97470966068977403726111106662, 417623098047757184755844912, -65847473433781766255637450, 1035689089174204990142479, 13644586177812118161156836], [0, 47354078105282793296285218891, 1146171360009032788871040184, -182585393288501170350542571, -4155979826516170422354532, 39313973287372071741662548], [0, -30038375626671029507448701180, 302644342699279309317915744, -47944506669502853215564452, -96821532938609650854222, 10113963832092939550824984], [113488078746850794224856515546642, -19697063413549917865483915, 220304601348192268896938170, 19697063413549917865483915, 0, -180910474521092433165970340], [-77124650941900259543239540900414, -265418361196065816710294844, 638681024026520408134070856, 265418361196065816710294844, 0, -107844301634388774713481168], [0, -10489835974836520489243795795, 1521527979382302293330783624, -240859238482245080533335885, 185093449822934665143208, 50668241059457293866987932], [0, -108175715025189513875263660104, -1540144386417309764100537024, 245119868731041113905886088, 4738778306126504712378972, -52601820428877393393318960], [0, 476527530005351964165288279150, 905373682111601790918920240, -142179732746438890489524270, 4391625954617724022392880, 29008022482488666624659240], [1987281873200250725167497691759682, -594386567347088666262382000, 1249538861913441692940324256, 594386567347088666262382000, 0, -60765727219264360415560256], [-9302120568177182392607647372654, 1377487690894852301602683731, -2832106100982393489028765802, -1377487690894852301602683731, 0, 77130719192688885823398340], [1948265088148411469567618750145506, -773943672296312852774713524, 1746897485118575416375323096, 773943672296312852774713524, 0, -199010140525949710825896048], [0, 320682828849649226265247809208, -5319183366559913643529884032, 840427559739655600546948392, -6661774871240223794812174, -175529638919666395105712888], [-93755945805429545106218739549934, -1779808966200531524037248227, 3043765382202359698628082058, 1779808966200531524037248227, 0, 515852550198703349446414396], [-2520491625918798427250437659237358, -1232648567004490762580168505, 2269699924787601488621471550, 1232648567004490762580168505, 0, 195597209221380036538865460], [0, -400066680535049824789872349036, -5043145754345954609952926560, 795985970156312528004277932, -9420403556738569643507900, -165592750863068201760162112], [-2090473627143778073339361909407854, 1353193471351482941191155281, -3368890605830920732373928782, -1353193471351482941191155281, 0, 662503663127954849991618220], [0, 137667193551293253196884920682, 4704740648261961045301298064, -741392506242261628448898474, 13217861497058263964276448, 153299925209516497786236216], [0, -97804402284361987833650744070, 10562940981626299408245528368, -1669357953183005377306840746, 11653883404345108745129671, 348990330479717951276149700], [0, -1236387654422646990945021098505, -6856602695715897543982092008, 1082795314820399258351686569, -10625420004816947920542496, -225719977855912065353925068], [3501087195725039894780325527445602, -1631299006900397237963696020, 3414950335223760130469581336, 1631299006900397237963696020, 0, -152352321422965654542189296], [-4278513494130268378775897504529214, -3177672257132998254929737564, 6164725857797344180293443080, 3177672257132998254929737564, 0, 190618656468652329566032048], [0, -540420393184468125412476382634, 14024963143842312577358341200, -2212586854493789768665115430, 30121162304661460312332225, 459466461513500696495322780], [0, 1961553965029147207822866648089, -9140708215931591076432447512, 1442147135394010627469120391, -19243745481842348622564244, -299558608402561742915064452], [-7234193069437953998066389700903278, -1635450553731326489386265095, 5575994710045013008309714306, 1635450553731326489386265095, 0, -2305093602582360029537184116], [0, 3484617366758355056470813484370, -439735575538938240134244240, 67112814774449671015696830, -9419942572058313770844405, -12145867832082390998916300], [-3770535910196215398480520699946014, 2355187549057226588952507548, -7387520634261561376071860360, -2355187549057226588952507548, 0, 2677145536147108198166845264], [0, 946243621953870865967677713700, 2136366197669820551996418464, -352235605784666387583275172, -52416091826043000689408432, 85189831075938818583722864], [-6337338797844442830207219993532654, -209318149377572347289033209, 5031399712479926203940004286, 209318149377572347289033209, 0, -4612763413724781509361937868], [12185043227699777692994078578037666, 5452651585711679206923443396, -15412971439499184421712929976, -5452651585711679206923443396, 0, 4507668268075826007866043184], [-4452844163391809555931818286609454, 7856483073684364804197185373, -23225685030143823603159296502, -7856483073684364804197185373, 0, 7512718882775093994764925756], [0, 6722885145491331640637766410162, -11908140481631716466572548912, 1883979686508662052528065550, -5534586561348955047205104, -395462126304697494206496936], [-257484021240075777095651209839598, 14324651110156602062497595555, -34568656511231377915624974026, -14324651110156602062497595555, 0, 5919354290918173790629782916], [11280150192548542540752468486277346, 8132050541219959630393791156, -8328958496800364099286234072, -8132050541219959630393791156, 0, -7935142585639555161501348240], [0, 8650695698020299595000823730636, -21322970837045437602735180640, 3390065131121720968614350868, 52230307210725055679802250, -724693776491041268272453288], [10488618642231978148506005173707266, -16958637322899482261343702112, 38178297205396171842103508800, 16958637322899482261343702112, 0, -4261022559597207319416104576], [0, -1232666067988288343047439569802, 7858126088171408729886454352, -1280680122442719531367535814, -136788094308424309258177031, 298414361421293440131729020], [-10208203552687316590805047836710254, 15163720417301515833161369321, -15390872401539934197084755870, -15163720417301515833161369321, 0, -14936568433063097469237982772], [0, 11329435290151129512127467157586, -8700133600820578824030472848, 1387843305391589936791750974, 38708069731243586200972899, -300326605289017583787941868], [0, -5778436703929212446766326830140, -181982005080314666281193065248, 28784036232589771390019166684, -111679644225190391886507426, -6036285597550438104870033528], [19994232948673937064060298574880722, -9160109824443913487700806415, 175959699898658592533746674, 9160109824443913487700806415, 0, 18144259948989168382867866156], [0, -2622009332429588529863427352098, 108053016144958613509913677840, -17109238913914806385189287534, -3167591111347172948582035, 3602611895794979696450077804], [44681333989152801283923666522476306, -2171982167306520664022143369, 19799535072747213271785904030, 2171982167306520664022143369, 0, -15455570738134171943741617292], [0, 5958209203571509123093169155801, 36023950237422877234141103720, -5622037284803748780157211385, 306580635455775432181737640, 1119043505125889125889573420], [31181728742272681022385252708921506, -10057441633453065400063431612, 24123930496893602027489330760, 10057441633453065400063431612, 0, -4009047229987471227362467536], [0, 2107085253541498313266295492770, 181775789713906485793306010448, -28867492750359195953413290594, -323722671215008885524396024, 6145519036120885229250039288], [52760453503631267187440990810295266, -21814940309441681877493404844, 86397268462840069500368492392, 21814940309441681877493404844, 0, -42767387843956705745381682704], [0, -8721995819674876532028684298876, -198640023094193643175199579296, 31377091949619980225385149532, -278418901102549790080439462, -6547089062845774828485202120], [-62766948866189920366721575907171374, 47678546005727292891301280393, -94217386148564683337662377566, -47678546005727292891301280393, 0, -1139705862889902444940183220], [0, 2012527837819175324577503028480, -134471625472037219524526354688, 21292748972711381314727171712, 5281023645580837539370824, -4483795788706728874161377376], [-65622910181839950613166250294771934, 31295637569338334137634578436, -91284336558958190303973124664, -31295637569338334137634578436, 0, 28693061420281522028703967792], [0, 12389824425621991204627345089088, -394268072290422012263113079680, 62413582565951656884371245824, -45733300119356464831219220, -13130073529648905351482110864], [-76355097068061103618198872140981614, -128018498751483084465102563559, 209882038043988289373599893954, 128018498751483084465102563559, 0, 46154959458977879556605233164], [0, -1757044353972098203734917015138, -59680946925746323638921722192, 9420369032740265004543795234, -109178364385885893570540424, -1960250667021974549678579960], [249628776714986554800130176043871186, -27618877880617812783899317279, 100333906888892612536944629458, 27618877880617812783899317279, 0, -45096151127656986969145994900], [0, -26744539982835023231057467866484, -409818155843347364092376999200, 65104269501955625334586646388, 811480600346097574851080680, -13877000021537204823039521488], [-60653559580651804384464574769562094, 151698827308433844347643699063, -282264652052048713720650817122, -151698827308433844347643699063, 0, -21133002564818974974636581004], [0, 96121386486955106635696802476500, -153315076995158589858065305184, 24613551031952108678838493932, 1269989403944994817418077292, -5449166407557284946580330784], [394835627028981006180953089616600066, -136721384178521386382623524084, 284674613902150200239795943000, 136721384178521386382623524084, 0, -11231845545107427474548894832], [0, 9648490756464254038777684318714, 919408827530394835993006915120, -145425389737548693064870511658, 553779830364334877583437135, 30499286296249338565744647268], [0, 6683952323743369707424074505591, 241434957511454357896969932312, -38280418376228372813425423191, -199562888430373049019439656, 8101048687296578076304181652], [0, 26552152049296787182595327869652, 632086261222711109182995650272, -100499402366541059315602859892, -1571541273544251356107057246, 21488619713702170667728403608], [105367517536205750188328954741111186, 110181310960691840940685007351, -369955712547665612234362487138, -110181310960691840940685007351, 0, 149593090626281930352992472436], [0, 3843766972816365739857410047377, -1384949433326867640248355744600, 218829964069521358234584669711, -1701360777122568017768711940, -45711284903662903203540201636], [0, -43709409003249478073954857334076, -360412449768217516832378188384, 57354676578053420411945761596, 1085145117821175925572056632, -12303120357026230807898488048], [0, -104842035591410975621061998759178, -286594964905607577781055397776, 46211784161390975609547227082, 3128430192511659228300459128, -10387413548190028386915302360], [1094561883943968046122517829892811922, 27685263535737384610838777715, -131042621142434876755621430826, -27685263535737384610838777715, 0, 75672094070960107533943875396], [465523029279412293984462299348727266, -299413159631415155614871850004, 471147341912468271881308714264, 299413159631415155614871850004, 0, 127678977350362039348434985744]]
